**************
Random sampler
**************

.. currentmodule:: glimix_core.random

.. autosummary::
  :toctree: _autosummary
  :template: class.rst

  GGPSampler
  GPSampler

.. autofunction:: glimix_core.random.bernoulli_sample

.. autofunction:: glimix_core.random.binomial_sample

.. autofunction:: glimix_core.random.poisson_sample
